@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.11.0";
+our $VERSION = "v6.12.0";
 
 1;
 __END__
@@ -542,6 +542,24 @@ L<https://rxjs.dev/api/operators/first>
         op_first(),
     )->subscribe($observer);
 
+=item op_ignore_elements
+
+L<https://rxjs.dev/api/operators/ignoreElements>
+
+    # (pause 3 seconds) complete
+    rx_interval(1)->pipe(
+        op_take(3),
+        op_ignore_elements(),
+    )->subscribe($observer);
+
+    # (pause 3 seconds) error: foo
+    rx_concat(
+        rx_interval(1)->pipe(op_take(3)),
+        rx_throw_error('foo'),
+    )->pipe(
+        op_ignore_elements(),
+    )->subscribe($observer);
+
 =item op_map
 
 L<https://rxjs.dev/api/operators/map>
