@@ -14,13 +14,13 @@ use Exporter 'import';
 our @EXPORT_OK = qw/
     op_audit_time op_buffer_count op_catch_error op_combine_latest_with op_concat_map op_debounce_time op_delay
     op_distinct_until_changed op_distinct_until_key_changed op_end_with op_exhaust_map op_filter op_finalize op_first
-    op_map op_map_to op_merge_map op_multicast op_pairwise op_pluck op_ref_count op_repeat op_retry op_sample_time
-    op_scan op_share op_skip op_skip_until op_start_with op_switch_map op_take op_take_until op_take_while op_tap
-    op_throttle_time op_with_latest_from
+    op_ignore_elements op_map op_map_to op_merge_map op_multicast op_pairwise op_pluck op_ref_count op_repeat op_retry
+    op_sample_time op_scan op_share op_skip op_skip_until op_start_with op_switch_map op_take op_take_until
+    op_take_while op_tap op_throttle_time op_with_latest_from
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.11.0";
+our $VERSION = "v6.12.0";
 
 sub op_audit_time {
     my ($duration) = @_;
@@ -519,6 +519,23 @@ sub op_first {
     };
 }
 
+sub op_ignore_elements {
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my %own_subscriber = %$subscriber;
+            delete $own_subscriber{next};
+
+            $source->subscribe(\%own_subscriber);
+
+            return;
+        });
+    }
+}
+
 sub op_map {
     my ($mapping_sub) = @_;
 
